Contributors
============

Colour - HDRI
-------------

-   **Thomas Mansencal**, *Visual Effects Artist @ Weta Digital*

    Project coordination, overall development.
    
About
-----

| **Colour - HDRI** by Colour Developers - 2015
| Copyright © 2015 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour-hdri <http://github.com/colour-science/colour-hdri>`_